//***************** (c) 2010 BTC Korporacja ***********************************
//                     http://www kamami.com
// PROJECT  : KAmodMEMS1
// BOARD    : ZL27ARM (with STM32F103VBT6)
//
//******************************************************************************
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//******************************************************************************
//
// DESCRIPTION :
//    KAmodMEMS1 + ZL27ARM demo. Position of KAmodMEMS1 is read and displayed on
//	  LCD.
//
//    Settings and connections on ZL27ARM:
//      JP11 (LED) - OFF
//		JP2 (LCD_PWM) - OFF
//      LCD_1602 connected to LCD socket
//
//	  KAmodMEMS1 to ZL27ARM connection
//		ZL27ARM			KAmodMEMS1
//		PA0  (JP6)		SGN (Con1)
//		PA1	 (JP6)		LC  (Con1)
//		PA2	 (JP6)		PC  (Con1)
//		GND  (JP6)		GND (Con1)
//		+3.3 (JP6)		+V  (Con1) 
//
//******************************************************************************


#include "./stm32f10x/stm32f10x_lib.h"
#include "hd44780.h"


char *positions[]={"Face top        ",
				   "Face bottom     ",
				   "Landscape right ",
				   "Landscape left  ",
				   "Portrait up     ",
				   "Portrait down   ",
				   "                ",
				   "                "};

void RCC_Config()
{
	ErrorStatus HSEStartUpStatus;
	RCC_DeInit();
	RCC_HSEConfig(RCC_HSE_ON);
	HSEStartUpStatus = RCC_WaitForHSEStartUp();
	if (HSEStartUpStatus == SUCCESS)
	{
		FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);
		FLASH_SetLatency(FLASH_Latency_2);
		RCC_HCLKConfig(RCC_SYSCLK_Div1);
		RCC_PCLK2Config(RCC_SYSCLK_Div1);
		RCC_PCLK1Config(RCC_SYSCLK_Div2);
		RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);
		RCC_PLLCmd(ENABLE);
		while (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
		RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
		while (RCC_GetSYSCLKSource() != 0x08);
	}
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);
}

void InitGPIO()
{
	GPIO_InitTypeDef GPIO_InitStructure; 

   	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING; 
   	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2; 
   	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz; 
   	GPIO_Init(GPIOB, &GPIO_InitStructure);  
}



int main()
{
	char KAmodMEMS1_pos = 0xFF;

	RCC_Config();
	InitGPIO();
	LCD_Initialize();
	

	LCD_WriteTextXY("KAmodMEMS1 demo ", 0, 0);
	LCD_WriteTextXY("                ", 0, 1);

	while(1)
	{
		// If KAmodMEMS1 position changed
		if ((GPIOA->IDR & 0x7) != KAmodMEMS1_pos)
		{
			// Display new position
			KAmodMEMS1_pos = GPIOA->IDR & 0x7;
			LCD_WriteTextXY(positions[KAmodMEMS1_pos], 0, 1);
		}
	}
}